==> mywwwatcher-3.1.tbz: www/mywwwatcher/queries.php <==
<?php
session_name ("mywauthid");
session_start();

include ("function.php");
include ("lang/" . $_SESSION['lang']) . ".lng";

authorization_check ();
$db = db_connect();

function print_result ($q)	{
	global $db, $f;

	$q = trim (str_replace ("\\n"," ",$q));
	$q = trim (str_replace ("\\t"," ",$q));

    $head = "";
	$text = "";
	$pocet_sloupcu = 1;

	echo "\n<table cellpadding=\"0\" cellspacing=\"0\" style=\"width: 100%\" class=\"border\">\n";
	echo "<tr bgcolor=\"" . $_SESSION['color_head'] . "\">";

	// pokud zobrazuju vice dotazu, tak se nesmi opakovat, pokud je destruktivni nebo updatovaci
	if ($f > 0 && $_SESSION[last_only] == 0 && (!( stristr($q,"select") || stristr($q,"show") || stristr($q,"describe")) ) )	{
		echo "<td><span style=\"width: 100%\"><b>$q</b></span></td></tr>\n";
		$text = QUERY_RELOAD;
	}
	else	{

        $query_start = time () + microtime ();
		if ($_SESSION[escape_query] == 1)	{
			$result = mysql_query (mysql_escape_string($q));
		}
		else	{
			$result = mysql_query ($q);
		}
        $query_end = time () + microtime ();

		if (!$result)	{
			$text = mysql_error();
			echo "<td><span style=\"width: 100%\"><b>$q</b></span></td></tr>\n";
		}
		else {
			$pocet_sloupcu = @mysql_num_fields($result);

			$reload_menu = false;

			echo "<td colspan=\"" . ($pocet_sloupcu) . "\"><span style=\"float: left;\"><b>$q</b>";
            echo "<br/>" . round (($query_end - $query_start),5) . "s</span>";
			echo "<span style=\"float: right;\">\n";
            echo "<a href=\"output.php?" . SID . "&q_index=$f&type=csv\"> -&gt; " . Q_TO_FILE . "</a><br/>\n";
            echo "<a href=\"query_archive.php?" . SID . "&action=add&q_index=$f\"> -&gt; " . Q_TO_ARCHIVE . "</a><br/>\n";
            echo "<a href=\"output.php?" . SID . "&q_index=$f&type=html\" target=\"_blank\"> -&gt; " . Q_TO_WINDOW . "&nbsp; </a>\n";
            echo "</tr>\n\n";

			if (eregi ("^describe .*$",$q))	{
				echo "<tr>\n";
				echo "<td><b>" . COL_NAME . "</b></td>\n";
				echo "<td><b>" . COL_TYPE . "</b></td>\n";
				echo "<td><b>" . COL_NULL . "</b></td>\n";
				echo "<td><b>" . COL_KEY . "</b></td>\n";
				echo "<td><b>" . COL_DEFAULT . "</b></td>\n";
				echo "<td><b>" . COL_EXTRA . "</b></td>\n";
				echo "</tr>";
		   	}
		   	elseif (eregi ("^(create database) .*$",$q))   {
                $words = explode (" ", $q);
                $_SESSION[xdb] = $words[2];
				$reload_menu = true;
            }
		   	elseif (eregi ("^(drop|insert|create|alter|delete) .*$",$q))   {
				$reload_menu = true;
		    }
		   	elseif (eregi ("^select .*$",$q))  {
				echo "<tr>\n";
				for ($ff = 0; $ff < $pocet_sloupcu; $ff++) {
					echo "<td><b>" . mysql_field_name($result,$ff) . "</b></td>\n";
				}
				echo "</tr>\n";
		   	}
		   	elseif (eregi ("^show .*$",$q))  {
				echo "<tr>\n";
				for ($ff = 0; $ff < $pocet_sloupcu; $ff++) {
					echo "<td><b>" . mysql_field_name($result,$ff) . "</b></td>\n";
				}
				echo "</tr>\n";
		   	}

            $text .= RESULT_INFO .": " . mysql_affected_rows ($db);

		 	while ($z = @mysql_fetch_row ($result))	{
				echo "\n<tr align=\"left\" valign=\"top\" onclick=\"highlight_row(this,'$_SESSION[color_right]','$_SESSION[color_hi]')\">\n";
				array_walk ($z,"ukaz");
				echo "</tr>\n";
			}
		}
	}
	echo "\n</table>\n";
	echo "<b>$text</b>";

    echo "<br/><a href=\"#top\">" . UP . "</a><br/><br/><br/>\n";

	if ($reload_menu)		{
		echo "<script language=\"javascript\">top.frm_left.document.location.href='menu.php?db=$_SESSION[xdb]&" . SID . "';</script>\n";

	}
}


function ukaz($prvek)	{
	if (strlen($prvek) <= $_SESSION[max_data] || $_SESSION[max_data] == -1)	{
		echo "<td>" . $prvek . "&nbsp;</td>\n";
	}
	else	{
		echo "<td>" . substr($prvek,0,$_SESSION[max_data]) . "...&nbsp;</td>\n";
	}
}



function format_query ($text)	{
    include ("include/words.inc.php");

	$text = trim ($text);
    $text = eregi_replace (" {2,}"," ",$text);
	$text = eregi_replace ("\,", ", ",$text);
	$text = eregi_replace ("=", " = ",$text);
	$text = eregi_replace ("\t{2,}","\\t",$text);
	$text = eregi_replace ("\n{2,}","\\n",$text);

    foreach ($words as $part) {
        $text = eregi_replace ("(^$part | $part )"," " . strtoupper($part) . " ",$text);
    }

	if (strlen($text) > 80)	{
        foreach ($words2 as $part) {
            $text = eregi_replace (" $part ","\\n" . strtoupper($part) . " ",$text);
        }
	}

	return (trim($text));
}

$rows = $_SESSION[query_format] == 1 ? 8 : 5;

include ("include/headers.inc.php");

?>

<body leftmargin="13" topmargin="13" bottommargin="30" rightmargin="5" bgcolor="<?php echo $_SESSION['color_right'];?>" onload="Body_OnLoad();">
<a name="top"/>
<?php

echo "<b>" . QUERY_ON . $_SESSION['xdb'] . "</b><br/><br/>\n";

// change last - musi to byt zde, form se odesila az dole
if ($_POST[last_only_current] == 0 && isset($_POST[last_only]))      {
    $_SESSION[last_only] = 1;
    $_SESSION[last_only_current] = 1;
}
elseif ($_POST[last_only_current] == 1 && !isset($_POST[last_only]))      {
    $_SESSION[last_only] = 0;
    $_SESSION[last_only_current] = 0;
}


//if (!empty($_SESSION[xdb]))	{

?>

<form action="<?php echo $_SERVER['PHP_SELF'] . "?" . SID ?>" method="post" name="dataform">
	<textarea name="current_query" style="width: 100%;" rows="<?php echo $rows; ?>" nowrap=nowrap>
<?php
    // from query archive
if ($_GET['current_query']) echo urldecode ($_GET['current_query']);
?></textarea>

	<input type="button" value="<?php echo HISTORY_UP; ?>" class="butonek" onclick="history_go('up');" />
	<input type="button" value="<?php echo HISTORY_DOWN; ?>" class="butonek" onclick="history_go('down');" />

	<input type="button" name="go" value="<?php echo GO; ?>" class="butonek" onclick="submit(this);" />
<br/><br/>

<?php
     echo "<input type=\"checkbox\" name=\"last_only\" value=\"$_SESSION[last_only]\" class=\"noborder\" ";
     echo $_SESSION['last_only'] == 1 ? "checked=\"checked\">\n" : ">\n";
     echo "&nbsp;" . LAST;
?>

	<input type="hidden" name="last_only_current" value="<?php echo $_SESSION[last_only];?>" />
	<input type="hidden" name="odes" value="1" />
	</form>

<br/><br/>

<?php


if ($_POST['odes']) 	{

	$q = stripslashes(ereg_replace ("(\r\n)|(\n)", " ", $_POST['current_query']));
	for ($f = $_SESSION['history_count']; $f > 0 ; $f--)	{
		$_SESSION['history_query'][$f] = $_SESSION['history_query'][$f-1];
	}

	$_SESSION['history_query'][0] =  $_SESSION[query_format] == 1 ? format_query ($q) : $q;

	$kolik = $_SESSION['last_only'] ? 1 : $_SESSION['last_count'];

	for ($f = 0; $f < $kolik ; $f++)	{
		if ($_SESSION['history_query'][$f])	 {
			print_result ($_SESSION['history_query'][$f]);
		}
	}

}

?>
<script language="JavaScript" type="text/javascript">
<!--
var history_query = new Array() ;
<?php
	//echo "window.alert (top.frm_left.qq);\n";
    echo "top.frm_left.qq = -1;\n";

	for ($f = 0; $f < $_SESSION['history_count']; $f++)	  {
		if ( ! empty ($_SESSION['history_query'][$f]))	 {
			echo "history_query[$f] = \"" . $_SESSION['history_query'][$f] . "\";\n";
	 	}
	}

?>
//-->
</script>

<?php

	if (empty($q))	{
		echo CTRL_ENTER_INFO;
	}
//}
//else	{	// nebyla zvolena databaze
//	echo NO_SEL_DB;
//}

	include ("include/foot.inc.php");
?>

==> mywwwatcher-3.2.tbz: www/mywwwatcher/queries.php <==
<?php
session_name ("mywauthid");
session_start();

include ("function.php");
include ("lang/" . $_SESSION['lang']) . ".lng";

authorization_check ();
$db = db_connect();

function print_result ($q)	{
	global $db, $f;

	$q = trim (str_replace ("\\n"," ",$q));
	$q = trim (str_replace ("\\t"," ",$q));

    $head = "";
	$text = "";
	$pocet_sloupcu = 1;
	$color = 0;


	echo "\n<table class=\"border\">\n";
	echo "<tr style=\"background-color: " . $_SESSION['color_head'] . ";\">";

	// pokud zobrazuju vice dotazu, tak se nesmi opakovat, pokud je destruktivni nebo updatovaci
	if ($f > 0 && $_SESSION[last_only] == 0 && (!( stristr($q,"select") || stristr($q,"show") || stristr($q,"describe")) ) )	{
		echo "<td><span style=\"float: left;\"><strong>$q</strong></span>";
		echo "<span style=\"float: right;\">\n";
        if ($_SESSION[qa_write])
            echo "<a href=\"query_archive.php?" . SID . "&action=add&q_index=$f\"> -&gt; " . Q_TO_ARCHIVE . "</a></span>\n";

        echo "</td></tr>\n";
		$text = QUERY_RELOAD;
	}
	else	{

        $query_start = time () + microtime ();
		if ($_SESSION[escape_query] == 1)	{
			$result = mysql_query (mysql_escape_string($q));
		}
		else	{
			$result = mysql_query ($q);
		}
        $query_end = time () + microtime ();

		if (!$result)	{
			$text = mysql_error();
			echo "<td><span style=\"float: left;\"><strong>$q</strong></span>";
            if ($_SESSION[qa_write])
                echo "<span style=\"float: right;\"><a href=\"query_archive.php?" . SID . "&action=add&q_index=$f\"> -&gt; " . Q_TO_ARCHIVE . "</a></span>\n";
            echo "</td></tr>\n";
		}
		else {
			$pocet_sloupcu = @mysql_num_fields($result);

			$reload_menu = false;

			echo "<td colspan=\"" . ($pocet_sloupcu) . "\"><span style=\"float: left;\"><strong>$q</strong>";
            echo "<br />" . round (($query_end - $query_start),5) . "s</span>\n";
			echo "<span style=\"float: right;\">\n";
            echo "<a href=\"output.php?" . SID . "&q_index=$f&type=csv\"> -&gt; " . Q_TO_FILE . "</a><br />\n";
            if ($_SESSION[qa_write])
                echo "<a href=\"query_archive.php?" . SID . "&action=add&q_index=$f\"> -&gt; " . Q_TO_ARCHIVE . "</a><br />\n";
            echo "<a href=\"output.php?" . SID . "&q_index=$f&type=html\" target=\"_blank\"> -&gt; " . Q_TO_WINDOW . "&nbsp; </a>\n";
            echo "</span>\n</td></tr>\n\n";

			if (eregi ("^describe .*$",$q))	{
				echo "<tr>\n";
				echo "<td><strong>" . COL_NAME . "</strong></td>\n";
				echo "<td><strong>" . COL_TYPE . "</strong></td>\n";
				echo "<td><strong>" . COL_NULL . "</strong></td>\n";
				echo "<td><strong>" . COL_KEY . "</strong></td>\n";
				echo "<td><strong>" . COL_DEFAULT . "</strong></td>\n";
				echo "<td><strong>" . COL_EXTRA . "</strong></td>\n";
				echo "</tr>";
		   	}
		   	elseif (eregi ("^(create database) .*$",$q))   {
                $words = explode (" ", $q);
                $_SESSION[xdb] = $words[2];
				$reload_menu = true;
            }
		   	elseif (eregi ("^(drop|insert|create|alter|delete) .*$",$q))   {
				$reload_menu = true;
		    }
		   	elseif (eregi ("^select .*$",$q))  {
				echo "<tr>\n";
				for ($ff = 0; $ff < $pocet_sloupcu; $ff++) {
					echo "<td><strong>" . mysql_field_name($result,$ff) . "</strong></td>\n";
				}
				echo "</tr>\n";
		   	}
		   	elseif (eregi ("^show .*$",$q))  {
				echo "<tr>\n";
				for ($ff = 0; $ff < $pocet_sloupcu; $ff++) {
					echo "<td><strong>" . mysql_field_name($result,$ff) . "</strong></td>\n";
				}
				echo "</tr>\n";
		   	}

            $text .= RESULT_INFO .": " . mysql_affected_rows ($db);

		 	while ($z = @mysql_fetch_row ($result))	{
				echo "\n<tr class=\"color_$color\" onclick=\"highlight_row(this,'$_SESSION[color_right]','$_SESSION[color_hi]')\">\n";
				array_walk ($z,"ukaz");
				echo "</tr>\n";
				if($color == 0) $color = 1; else $color = 0;
			}
		}
	}
	echo "\n</table>\n";
	echo "<strong>$text</strong>";

    echo "<br /><a href=\"#top\">" . UP . "</a><br /><br /><br />\n";

	if ($reload_menu)		{
		echo "<script language=\"javascript\">top.frm_left.document.location.href='menu.php?db=$_SESSION[xdb]&" . SID . "';</script>\n";

	}
}


function ukaz($prvek)	{
	if (strlen($prvek) <= $_SESSION[max_data] || $_SESSION[max_data] == -1)	{
		echo "<td>" . $prvek . "</td>\n";
	}
	else	{
		echo "<td>" . substr($prvek,0,$_SESSION[max_data]) . "...</td>\n";
	}
}



function format_query ($text)	{
    include ("include/words.inc.php");

	$text = trim ($text);
// toto se musi resit pouze v prikazech, ne v apostrofech
    $text = eregi_replace (" {2,}"," ",$text);
	$text = eregi_replace ("\,", ", ",$text);
	$text = eregi_replace ("!=", " != ",$text);
// tady je to blbe, udela mi to mezeru mezi !=
	$text = eregi_replace ("=", " = ",$text);
	$text = eregi_replace ("\t{2,}","\\t",$text);
	$text = eregi_replace ("\n{2,}","\\n",$text);

    foreach ($words as $part) {
        $text = eregi_replace ("(^$part | $part )"," " . strtoupper($part) . " ",$text);
    }

	if (strlen($text) > 80)	{
        foreach ($words2 as $part) {
            $text = eregi_replace (" $part ","\\n" . strtoupper($part) . " ",$text);
        }
	}

	return (trim($text));
}

$rows = $_SESSION[query_format] == 1 ? 8 : 5;

include ("include/headers.inc.php");

?>

<body id="frm_right" bgcolor="<?php echo $_SESSION['color_right'];?>" onload="Body_OnLoad();">
<a name="top"></a>
<?php

echo "<strong>" . QUERY_ON . $_SESSION['xdb'] . "</strong><br /><br />\n";

// change last - musi to byt zde, form se odesila az dole
if ($_POST[last_only_current] == 0 && isset($_POST[last_only]))      {
    $_SESSION[last_only] = 1;
    $_SESSION[last_only_current] = 1;
}
elseif ($_POST[last_only_current] == 1 && !isset($_POST[last_only]))      {
    $_SESSION[last_only] = 0;
    $_SESSION[last_only_current] = 0;
}


?>

<form action="<?php echo $_SERVER['PHP_SELF'] . "?" . SID ?>" method="post" name="dataform">
	<textarea name="current_query" style="width: 100%;" rows="<?php echo $rows; ?>">
<?php
    // from query archive
if ($_GET['current_query']) echo urldecode ($_GET['current_query']);
?></textarea>

	<input type="button" value="<?php echo HISTORY_UP; ?>" class="butonek" onclick="history_go('up');" />
	<input type="button" value="<?php echo HISTORY_DOWN; ?>" class="butonek" onclick="history_go('down');" />

	<input type="button" name="go" value="<?php echo GO; ?>" class="butonek" onclick="submit(this);" />
<br /><br />

<?php
     echo "<input type=\"checkbox\" name=\"last_only\" value=\"$_SESSION[last_only]\" class=\"noborder\" ";
     echo $_SESSION['last_only'] == 1 ? "checked=\"checked\" />\n" : " />\n";
     echo "&nbsp;" . LAST;
?>

	<input type="hidden" name="last_only_current" value="<?php echo $_SESSION[last_only];?>" />
	<input type="hidden" name="odes" value="1" />
	</form>

<br /><br />

<?php


if ($_POST['odes']) 	{

	$q = stripslashes(ereg_replace ("(\r\n)|(\n)", " ", $_POST['current_query']));
	for ($f = $_SESSION['history_count']; $f > 0 ; $f--)	{
		$_SESSION['history_query'][$f] = $_SESSION['history_query'][$f-1];
	}

	$_SESSION['history_query'][0] =  $_SESSION[query_format] == 1 ? format_query ($q) : $q;

	$kolik = $_SESSION['last_only'] ? 1 : $_SESSION['last_count'];

	for ($f = 0; $f < $kolik ; $f++)	{
		if ($_SESSION['history_query'][$f])	 {
			print_result ($_SESSION['history_query'][$f]);
		}
	}

}

?>
<script language="JavaScript" type="text/javascript">
<!--
var history_query = new Array() ;
<?php
    echo "top.frm_left.qq = -1;\n";

	for ($f = 0; $f < $_SESSION['history_count']; $f++)	  {
		if ( ! empty ($_SESSION['history_query'][$f]))	 {
			echo "history_query[$f] = \"" . $_SESSION['history_query'][$f] . "\";\n";
	 	}
	}

?>
//-->
</script>

<?php

	if (empty($q))	{
		echo CTRL_ENTER_INFO;
	}

	include ("include/foot.inc.php");
?>
